@@ -1,4 +1,4 @@
-weightit.fit <- function(covs, treat, method = "ps", s.weights = NULL, by.factor = NULL,
+weightit.fit <- function(covs, treat, method = "glm", s.weights = NULL, by.factor = NULL,
                          estimand = "ATE", focal = NULL, stabilize = FALSE, ps = NULL, moments = NULL, int = FALSE,
                          subclass = NULL, is.MSM.method = FALSE, missing = NULL, verbose = FALSE, include.obj = FALSE, ...){
 
@@ -7,48 +7,52 @@ weightit.fit <- function(covs, treat, method = "ps", s.weights = NULL, by.factor
   #Checks
   if (!check_if_call_from_fun(weightit) && !check_if_call_from_fun(weightitMSM)) {
 
-    if (missing(covs) || !is.matrix(covs) || !is.numeric(covs)) {
-      stop("'covs' must be a numeric matrix of covariates.", call. = FALSE)
+    chk::chk_not_missing(covs, "`covs`")
+    chk::chk_matrix(covs)
+    chk::chk_numeric(covs)
+
+    chk::chk_not_missing(treat, "`treat`")
+    chk::chk_vector(treat)
+    chk::chk_numeric(treat)
+    chk::chk_not_any_na(treat)
+
+    if (length(treat) != nrow(covs)) {
+      .err("`treat` and `'covs` must contain the same number of units")
     }
 
-    if (missing(treat) || is_not_null(dim(treat)) || !is.atomic(treat)) {
-      stop("'treat' must be an atomic vector.", call. = FALSE)
-    }
-    else if (length(treat) != nrow(covs)) {
-      stop("'treat' and 'covs' must contain the same number of units.", call. = FALSE)
-    }
-    if (anyNA(treat)) {
-      stop("No missing values are allowed in 'treat'.", call. = FALSE)
-    }
     if (!has.treat.type(treat)) treat <- assign.treat.type(treat)
     treat.type <- get.treat.type(treat)
 
     check.acceptable.method(method, msm = FALSE, force = FALSE)
 
     if (is_not_null(ps)) {
-      if (!is.numeric(ps) || is_not_null(dim(ps))) {
-        stop("'ps' must be a numeric vector.", call. = FALSE)
+      chk::chk_vector(ps)
+      chk::chk_numeric(ps)
+
+      if (length(ps) != length(treat)) {
+        .err("`ps` and `treat` must be the same length")
       }
-      else if (length(ps) != length(treat)) {
-        stop("'ps' and 'treat' must be the same length.", call. = FALSE)
-      }
-      method <- "ps"
+
+      method <- "glm"
     }
 
     if (is_null(s.weights)) s.weights <- rep(1, length(treat))
-    else if (!is.numeric(s.weights) || is_not_null(dim(s.weights))) {
-      stop("'s.weights' must be a numeric vector.", call. = FALSE)
-    }
-    else if (length(s.weights) != length(treat)) {
-      stop("'s.weights' and 'treat' must be the same length.", call. = FALSE)
+    else {
+      chk::chk_vector(s.weights)
+      chk::chk_numeric(s.weights)
+
+      if (length(s.weights) != length(treat)) {
+        .err("`s.weights` and `treat` must be the same length")
+      }
     }
 
     if (is_null(by.factor)) by.factor <- factor(rep(1, length(treat)), levels = 1)
-    else if (!is.factor(by.factor)) {
-      stop("'by.factor' must be a factor.", call. = FALSE)
-    }
-    else if (length(by.factor) != length(treat)) {
-      stop("'by.factor' and 'treat' must be the same length.", call. = FALSE)
+    else {
+      chk::chk_factor(by.factor)
+
+      if (length(by.factor) != length(treat)) {
+        .err("`by.factor` and `treat` must be the same length")
+      }
     }
 
     #Process estimand and focal
@@ -57,13 +61,12 @@ weightit.fit <- function(covs, treat, method = "ps", s.weights = NULL, by.factor
     focal <- f.e.r[["focal"]]
     estimand <- f.e.r[["estimand"]]
 
+    .chk_null_or(missing, chk::chk_string)
+
     if (is_null(missing)) {
       if (anyNA(covs)) missing <- "ind"
       else missing <- ""
     }
-    else if (!is.character(missing) || is_not_null(dim(missing))) {
-      stop("'missing' must be NULL or a character vector.", call. = FALSE)
-    }
     else if (missing != "" && anyNA(covs)) {
       missing <- process.missing(missing, method, treat.type)
     }
@@ -89,10 +92,6 @@ weightit.fit <- function(covs, treat, method = "ps", s.weights = NULL, by.factor
 
   obj <- NULL
 
-  if (verbose) eval.verbose <- base::eval
-  else eval.verbose <- utils::capture.output
-
-  eval.verbose({
   for (i in levels(by.factor)) {
     #Run method
     if (is.function(method)) {
@@ -104,6 +103,7 @@ weightit.fit <- function(covs, treat, method = "ps", s.weights = NULL, by.factor
                                 subset = by.factor == i,
                                 stabilize = stabilize,
                                 missing = missing,
+                                verbose = verbose,
                                 ...)
       }
       else {
@@ -120,32 +120,34 @@ weightit.fit <- function(covs, treat, method = "ps", s.weights = NULL, by.factor
                              missing = missing,
                              moments = moments,
                              int = int,
+                             verbose = verbose,
                              ...)
       }
-
     }
-    else if (method == "ps") {
+    else if (method == "glm") {
       if (treat.type %in% c("binary", "multinomial")) {
-        obj <- weightit2ps(covs = covs,
-                           treat = treat,
-                           s.weights = s.weights,
-                           subset = by.factor == i,
-                           estimand = estimand,
-                           focal = focal,
-                           stabilize = stabilize,
-                           subclass = subclass,
-                           ps = ps,
-                           missing = missing,
-                           ...)
+        obj <- weightit2glm(covs = covs,
+                            treat = treat,
+                            s.weights = s.weights,
+                            subset = by.factor == i,
+                            estimand = estimand,
+                            focal = focal,
+                            stabilize = stabilize,
+                            subclass = subclass,
+                            ps = ps,
+                            missing = missing,
+                            verbose = verbose,
+                            ...)
       }
       else if (treat.type == "continuous") {
-        obj <- weightit2ps.cont(covs = covs,
-                                treat = treat,
-                                s.weights = s.weights,
-                                subset = by.factor == i,
-                                ps = ps,
-                                missing = missing,
-                                ...)
+        obj <- weightit2glm.cont(covs = covs,
+                                 treat = treat,
+                                 s.weights = s.weights,
+                                 subset = by.factor == i,
+                                 ps = ps,
+                                 missing = missing,
+                                 verbose = verbose,
+                                 ...)
       }
     }
     else if (method == "optweight") {
@@ -157,6 +159,7 @@ weightit.fit <- function(covs, treat, method = "ps", s.weights = NULL, by.factor
                                       moments = moments,
                                       int = int,
                                       missing = missing,
+                                      verbose = verbose,
                                       ...)
       }
       else {
@@ -169,7 +172,9 @@ weightit.fit <- function(covs, treat, method = "ps", s.weights = NULL, by.factor
                                     focal = focal,
                                     moments = moments,
                                     int = int,
-                                    missing = missing, ...)
+                                    missing = missing,
+                                    verbose = verbose,
+                                    ...)
         }
         else if (treat.type == "continuous") {
           obj <- weightit2optweight.cont(covs = covs,
@@ -179,6 +184,7 @@ weightit.fit <- function(covs, treat, method = "ps", s.weights = NULL, by.factor
                                          moments = moments,
                                          int = int,
                                          missing = missing,
+                                         verbose = verbose,
                                          ...)
 
         }
@@ -195,6 +201,7 @@ weightit.fit <- function(covs, treat, method = "ps", s.weights = NULL, by.factor
                             stabilize = stabilize,
                             subclass = subclass,
                             missing = missing,
+                            verbose = verbose,
                             ...)
       }
       else {
@@ -203,13 +210,14 @@ weightit.fit <- function(covs, treat, method = "ps", s.weights = NULL, by.factor
                                  s.weights = s.weights,
                                  subset = by.factor == i,
                                  missing = missing,
+                                 verbose = verbose,
                                  ...)
       }
 
     }
     else if (method == "cbps") {
       if (is.MSM.method) {
-        obj <- weightit2cbps.msm()
+        # obj <- weightit2cbps.msm()
       }
       else {
         if (treat.type %in% c("binary", "multinomial")) {
@@ -222,6 +230,7 @@ weightit.fit <- function(covs, treat, method = "ps", s.weights = NULL, by.factor
                                estimand = estimand,
                                focal = focal,
                                missing = missing,
+                               verbose = verbose,
                                ...)
         }
         else if (treat.type == "continuous") {
@@ -230,6 +239,7 @@ weightit.fit <- function(covs, treat, method = "ps", s.weights = NULL, by.factor
                                     subset = by.factor == i,
                                     s.weights = s.weights,
                                     missing = missing,
+                                    verbose = verbose,
                                     ...)
 
         }
@@ -245,6 +255,7 @@ weightit.fit <- function(covs, treat, method = "ps", s.weights = NULL, by.factor
                                moments = moments,
                                int = int,
                                missing = missing,
+                               verbose = verbose,
                                ...)
       }
       else if (treat.type == "continuous") {
@@ -255,6 +266,7 @@ weightit.fit <- function(covs, treat, method = "ps", s.weights = NULL, by.factor
                                     moments = moments,
                                     int = int,
                                     missing = missing,
+                                    verbose = verbose,
                                     ...)
       }
 
@@ -271,6 +283,7 @@ weightit.fit <- function(covs, treat, method = "ps", s.weights = NULL, by.factor
                              moments = moments,
                              int = int,
                              missing = missing,
+                             verbose = verbose,
                              ...)
       }
       else {
@@ -281,6 +294,7 @@ weightit.fit <- function(covs, treat, method = "ps", s.weights = NULL, by.factor
                                   moments = moments,
                                   int = int,
                                   missing = missing,
+                                  verbose = verbose,
                                   ...)
       }
     }
@@ -295,6 +309,7 @@ weightit.fit <- function(covs, treat, method = "ps", s.weights = NULL, by.factor
                               stabilize = stabilize,
                               subclass = subclass,
                               missing = missing,
+                              verbose = verbose,
                               ...)
       }
       else if (treat.type == "continuous") {
@@ -304,27 +319,28 @@ weightit.fit <- function(covs, treat, method = "ps", s.weights = NULL, by.factor
                                    subset = by.factor == i,
                                    stabilize = stabilize,
                                    missing = missing,
+                                   verbose = verbose,
                                    ...)
       }
     }
-    else if (method == "ebcw") {
-      if (treat.type %in% c("binary", "multinomial")) {
-        obj <- weightit2ebcw(covs = covs,
-                             treat = treat,
-                             s.weights = s.weights,
-                             subset = by.factor == i,
-                             estimand = estimand,
-                             focal = focal,
-                             #stabilize = stabilize,
-                             moments = moments,
-                             int = int,
-                             missing = missing,
-                             ...)
-      }
-      else {
-        stop("Empirical balancing calibration weights are not compatible with continuous treatments.", call. = FALSE)
-      }
-    }
+    # else if (method == "ebcw") {
+    #   if (treat.type %in% c("binary", "multinomial")) {
+    #     obj <- weightit2ebcw(covs = covs,
+    #                          treat = treat,
+    #                          s.weights = s.weights,
+    #                          subset = by.factor == i,
+    #                          estimand = estimand,
+    #                          focal = focal,
+    #                          #stabilize = stabilize,
+    #                          moments = moments,
+    #                          int = int,
+    #                          missing = missing,
+    #                          ...)
+    #   }
+    #   else {
+    #     stop("Empirical balancing calibration weights are not compatible with continuous treatments")
+    #   }
+    # }
     else if (method == "energy") {
       if (treat.type %in% c("binary", "multinomial")) {
         obj <- weightit2energy(covs = covs,
@@ -334,21 +350,22 @@ weightit.fit <- function(covs, treat, method = "ps", s.weights = NULL, by.factor
                                estimand = estimand,
                                focal = focal,
                                stabilize = stabilize,
+                               missing = missing,
                                moments = moments,
                                int = int,
-                               missing = missing,
+                               verbose = verbose,
                                ...)
       }
       else {
-        stop("Energy balancing weights are not compatible with continuous treatments.", call. = FALSE)
-        # obj <- weightit2energy.cont(covs = covs,
-        #                             treat = treat,
-        #                             subset = by.factor == i,
-        #                             s.weights = s.weights,
-        #                             moments = moments,
-        #                             int = int,
-        #                             missing = missing,
-        #                             ...)
+        obj <- weightit2energy.cont(covs = covs,
+                                    treat = treat,
+                                    subset = by.factor == i,
+                                    s.weights = s.weights,
+                                    missing = missing,
+                                    moments = moments,
+                                    int = int,
+                                    verbose = verbose,
+                                    ...)
       }
     }
     else if (method == "bart") {
@@ -362,6 +379,7 @@ weightit.fit <- function(covs, treat, method = "ps", s.weights = NULL, by.factor
                              stabilize = stabilize,
                              subclass = subclass,
                              missing = missing,
+                             verbose = verbose,
                              ...)
       }
       else if (treat.type == "continuous") {
@@ -371,6 +389,7 @@ weightit.fit <- function(covs, treat, method = "ps", s.weights = NULL, by.factor
                                   subset = by.factor == i,
                                   stabilize = stabilize,
                                   missing = missing,
+                                  verbose = verbose,
                                   ...)
       }
     }
@@ -385,17 +404,21 @@ weightit.fit <- function(covs, treat, method = "ps", s.weights = NULL, by.factor
     #                          missing = missing,
     #                          ...)
     #   }
-    #   else stop("Kernel balancing is not compatible with continuous treatments.", call. = FALSE)
+    #   else stop("Kernel balancing is not compatible with continuous treatments")
     # }
     else {
-      stop("Invalid argument to 'method'.", call. = FALSE)
+      .err("invalid argument to `method`")
     }
 
     #Extract weights
-    if (is_null(obj)) stop("No object was created. This is probably a bug,\n     and you should report it at https://github.com/ngreifer/WeightIt/issues.", call. = FALSE)
-    if (is_null(obj$w) || all(is.na(obj$w))) warning("No weights were estimated. This is probably a bug,\n     and you should report it at https://github.com/ngreifer/WeightIt/issues.", call. = FALSE)
+    if (is_null(obj)) {
+      .err("no object was created. This is probably a bug,\n     and you should report it at https://github.com/ngreifer/WeightIt/issues")
+    }
+    if (is_null(obj$w) || all(is.na(obj$w))) {
+      .wrn("No weights were estimated. This is probably a bug,\n     and you should report it at https://github.com/ngreifer/WeightIt/issues")
+    }
     if (any(!is.finite(obj$w))) {
-      warning("Some weights were estimated as NA, which means a value was impossible to compute (e.g., Inf). Check for extreme values of the treatment or covariates and try removing them. Non-finite weights will be set to 0.", call. = FALSE)
+      .wrn("Some weights were estimated as `NA`, which means a value was impossible to compute (e.g., Inf). Check for extreme values of the treatment or covariates and try removing them. Non-finite weights will be set to 0")
       obj$w[!is.finite(obj$w)] <- 0
     }
     # else if (any(!is.finite(obj$w))) probably.a.bug()
@@ -407,7 +430,7 @@ weightit.fit <- function(covs, treat, method = "ps", s.weights = NULL, by.factor
     info[[i]] <- obj$info
 
   }
-  })
+
 
   if (include.obj) {
     if (nlevels(by.factor) == 1) fit.obj <- fit.obj[[1]]
@@ -420,5 +443,6 @@ weightit.fit <- function(covs, treat, method = "ps", s.weights = NULL, by.factor
   if (all(is.na(out$ps))) out$ps <- NULL
 
   class(out) <- "weightit.fit"
-  return(out)
+
+  out
 }
